/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { ref, reactive, watch } from 'vue'
import * as Fields from '../fields/index'
import type { IJsonItem, INodeData, ITaskData } from '../types'

export function useDependent({
  projectCode,
  from = 0,
  readonly,
  data
}: {
  projectCode: number
  from?: number
  readonly?: boolean
  data?: ITaskData
}) {
  const taskCodeOptions = ref([] as { label: string; value: number }[])
  const model = reactive({
    taskType: 'DEPENDENT',
    name: '',
    flag: 'YES',
    description: '',
    timeoutShowFlag: false,
    localParams: [],
    environmentCode: null,
    failRetryInterval: 1,
    failRetryTimes: 0,
    workerGroup: 'default',
    delayTime: 0,
    relation: 'AND',
    dependTaskList: [],
    preTasks: [],
    timeoutNotifyStrategy: [],
    timeout: 30,
    timeoutFlag: false,
    ...data
  } as INodeData)

  let extra: IJsonItem[] = []
  if (from === 1) {
    extra = [
      Fields.useTaskType(model, readonly),
      Fields.useProcessName({
        model,
        projectCode,
        isCreate: !data?.id,
        from,
        processName: data?.processName
      })
    ]
  }

  watch(
    () => model.preTasks,
    () => {
      taskCodeOptions.value =
        model.preTaskOptions
          ?.filter((task: { code: number }) =>
            model.preTasks?.includes(task.code)
          )
          .map((task: { code: number; name: string }) => ({
            value: task.code,
            label: task.name
          })) || []
    }
  )

  return {
    json: [
      Fields.useName(),
      ...extra,
      Fields.useRunFlag(),
      Fields.useDescription(),
      Fields.useTaskPriority(),
      Fields.useWorkerGroup(),
      Fields.useEnvironmentName(model, !data?.id),
      ...Fields.useTaskGroup(model, projectCode),
      ...Fields.useFailed(),
      ...Fields.useDependent(model),
      Fields.usePreTasks(model, data?.code)
    ] as IJsonItem[],
    model
  }
}
